@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2005, 2006 by Pino Toscano, toscano.pino@tiscali.it     *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005, 2006 Pino Toscano <toscano.pino@tiscali.it>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kalziumnumerationtype.h"
 
@@ -31,13 +18,13 @@ KalziumNumerationTypeFactory::KalziumNumerationTypeFactory()
     m_numerations << KalziumOldIUPACNumerationType::instance();
 }
 
-KalziumNumerationTypeFactory* KalziumNumerationTypeFactory::instance()
+KalziumNumerationTypeFactory *KalziumNumerationTypeFactory::instance()
 {
     static KalziumNumerationTypeFactory kntf;
     return &kntf;
 }
 
-KalziumNumerationType* KalziumNumerationTypeFactory::build(int id) const
+KalziumNumerationType *KalziumNumerationTypeFactory::build(int id) const
 {
     if ((id < 0) || (id >= m_numerations.count())) {
         return nullptr;
@@ -46,7 +33,7 @@ KalziumNumerationType* KalziumNumerationTypeFactory::build(int id) const
     return m_numerations.at(id);
 }
 
-KalziumNumerationType* KalziumNumerationTypeFactory::build(const QByteArray& id) const
+KalziumNumerationType *KalziumNumerationTypeFactory::build(const QByteArray &id) const
 {
     for (int i = 0; i < m_numerations.count(); ++i) {
         if (m_numerations.at(i)->name() == id) {
@@ -67,24 +54,19 @@ QStringList KalziumNumerationTypeFactory::numerations() const
     return l;
 }
 
-
-KalziumNumerationType* KalziumNumerationType::instance()
+KalziumNumerationType *KalziumNumerationType::instance()
 {
     return nullptr;
 }
 
-KalziumNumerationType::KalziumNumerationType()
-{
-}
+KalziumNumerationType::KalziumNumerationType() = default;
 
-KalziumNumerationType::~KalziumNumerationType()
-{
-}
+KalziumNumerationType::~KalziumNumerationType() = default;
 
 QString KalziumNumerationType::item(const int num) const
 {
     if ((num < 0) || (num >= m_items.count())) {
-        return QString();
+        return {};
     }
 
     return m_items.at(num);
@@ -95,15 +77,14 @@ QStringList KalziumNumerationType::items() const
     return m_items;
 }
 
-
-KalziumNoneNumerationType* KalziumNoneNumerationType::instance()
+KalziumNoneNumerationType *KalziumNoneNumerationType::instance()
 {
     static KalziumNoneNumerationType knnt;
     return &knnt;
 }
 
 KalziumNoneNumerationType::KalziumNoneNumerationType()
-        : KalziumNumerationType()
+    : KalziumNumerationType()
 {
 }
 
@@ -120,22 +101,22 @@ QString KalziumNoneNumerationType::description() const
 QString KalziumNoneNumerationType::item(const int num) const
 {
     Q_UNUSED(num);
-    return QString();
+    return {};
 }
 
 QStringList KalziumNoneNumerationType::items() const
 {
-    return QStringList();
+    return {};
 }
 
-KalziumIUPACNumerationType* KalziumIUPACNumerationType::instance()
+KalziumIUPACNumerationType *KalziumIUPACNumerationType::instance()
 {
     static KalziumIUPACNumerationType kint;
     return &kint;
 }
 
 KalziumIUPACNumerationType::KalziumIUPACNumerationType()
-        : KalziumNumerationType()
+    : KalziumNumerationType()
 {
     // cache them
     m_items << QStringLiteral("1");
@@ -168,14 +149,14 @@ QString KalziumIUPACNumerationType::description() const
     return i18n("IUPAC");
 }
 
-KalziumCASNumerationType* KalziumCASNumerationType::instance()
+KalziumCASNumerationType *KalziumCASNumerationType::instance()
 {
     static KalziumCASNumerationType kcnt;
     return &kcnt;
 }
 
 KalziumCASNumerationType::KalziumCASNumerationType()
-        : KalziumNumerationType()
+    : KalziumNumerationType()
 {
     // cache them
     m_items << QStringLiteral("IA");
@@ -208,14 +189,14 @@ QString KalziumCASNumerationType::description() const
     return i18n("CAS");
 }
 
-KalziumOldIUPACNumerationType* KalziumOldIUPACNumerationType::instance()
+KalziumOldIUPACNumerationType *KalziumOldIUPACNumerationType::instance()
 {
     static KalziumOldIUPACNumerationType koint;
     return &koint;
 }
 
 KalziumOldIUPACNumerationType::KalziumOldIUPACNumerationType()
-        : KalziumNumerationType()
+    : KalziumNumerationType()
 {
     // cache them
     m_items << QStringLiteral("1A");
